;; Generated package description from jinx.el  -*- mode: lisp-data; no-byte-compile: t; lexical-binding:t -*-
(define-package "jinx" "2.8.0.20260628.1" "Enchanted Spell Checker" '((emacs "29.1") (compat "31")) :commit "80b3618d401a654137a48be7d4f90b67cad92748" :authors '(("Daniel Mendler" . "mail@daniel-mendler.de")) :maintainer '("Daniel Mendler" . "mail@daniel-mendler.de") :keywords '("convenience" "text") :url "https://github.com/minad/jinx")
